@@ -28,7 +28,7 @@ from fast_sql.fastsql.sql import Read_sql
 
 os.environ["NLS_LANG"] = "SIMPLIFIED CHINESE_CHINA.UTF8"
 
-__version__ = "1.4.1"
+__version__ = "1.4.3"
 
 
 def read_sql(
@@ -290,6 +290,7 @@ def to_sql(
     delete_sql=None,
     desc="rsync the scheduler",
     auto_order=False,
+    extra_param=None,
     **kwargs,
 ):
     """
@@ -428,6 +429,7 @@ def to_sql(
         delete_sql=delete_sql,
         desc=desc,
         auto_order=auto_order,
+        extra_param=extra_param,
         **kwargs,
     )
 
