@@ -1,4 +1,6 @@
+import copy
 import os
+import inspect
 import uuid
 import re
 import sys
@@ -254,6 +256,7 @@ class to_sql(Read_sql):
         self.task_count = None
         self.execute_count = 0
         self.data_processing = kwargs.pop("data_processing", None)
+        self.extra_param = kwargs.pop('extra_param',None)
         super().__init__(*args, **kwargs)
         if to_db is not None:
             self.to_db = DB_Pool(to_db, num=8, encoding=kwargs.get("encoding"))
@@ -402,7 +405,10 @@ class to_sql(Read_sql):
         if self.columns_upper:
             df.columns = [i.upper() for i in df.columns]
         if self.data_processing is not None:
-            df = self.data_processing(df)
+            if 'extra_param' in inspect.signature(self.data_processing).parameters:
+                df = self.data_processing(df,extra_param=copy.deepcopy(self.extra_param))
+            else:
+                df = self.data_processing(df)
 
         c = [
             (column, str(date))
@@ -452,3 +458,4 @@ class to_sql(Read_sql):
             if self.tqdm_w is not None:
                 self.tqdm_w.update(self.task_count - self.tqdm_w.n)
         sys.stdout.flush()
+        self.db_pool.dispose()
